@@ -12,9 +12,9 @@ func TestFishFeatures(t *testing.T) {
 
 	want := `// these are the features
 enable_poshtooltips
-set --global fish_transient_prompt 1
+set --global _omp_transient_prompt 1
 set --global _omp_ftcs_marks 1
-"$_omp_executable" upgrade
+"$_omp_executable" upgrade --auto
 "$_omp_executable" notice
 set --global _omp_prompt_mark 1`
 
